# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/iam/v1beta1/iam_policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from protopia.api.iam.v1beta1 import policy_pb2 as protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/iam/v1beta1/iam_policy.proto',
  package='protopia.cloud.iam.v1beta1',
  syntax='proto3',
  serialized_options=b'Z4github.com/protopia-ai/cloud/pkg/api/iam/v1beta1;iam',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)protopia/api/iam/v1beta1/iam_policy.proto\x12\x1aprotopia.cloud.iam.v1beta1\x1a%protopia/api/iam/v1beta1/policy.proto\"[\n\x13SetIamPolicyRequest\x12\x10\n\x08resource\x18\x01 \x01(\t\x12\x32\n\x06policy\x18\x02 \x01(\x0b\x32\".protopia.cloud.iam.v1beta1.Policy\"!\n\x13GetIamPolicyRequest\x12\n\n\x02id\x18\x01 \x01(\t\"?\n\x16ListIamPoliciesRequest\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"h\n\x17ListIamPoliciesResponse\x12\x34\n\x08policies\x18\x01 \x03(\x0b\x32\".protopia.cloud.iam.v1beta1.Policy\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"$\n\x16\x44\x65leteIamPolicyRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x19\n\x17\x44\x65leteIamPolicyResponse\"=\n\x19TestIamPermissionsRequest\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\"-\n\x1aTestIamPermissionsResponse\x12\x0f\n\x07\x61llowed\x18\x01 \x01(\x08\x32\xd3\x04\n\tIAMPolicy\x12\x63\n\x0cSetIamPolicy\x12/.protopia.cloud.iam.v1beta1.SetIamPolicyRequest\x1a\".protopia.cloud.iam.v1beta1.Policy\x12\x63\n\x0cGetIamPolicy\x12/.protopia.cloud.iam.v1beta1.GetIamPolicyRequest\x1a\".protopia.cloud.iam.v1beta1.Policy\x12z\n\x0fListIamPolicies\x12\x32.protopia.cloud.iam.v1beta1.ListIamPoliciesRequest\x1a\x33.protopia.cloud.iam.v1beta1.ListIamPoliciesResponse\x12z\n\x0f\x44\x65leteIamPolicy\x12\x32.protopia.cloud.iam.v1beta1.DeleteIamPolicyRequest\x1a\x33.protopia.cloud.iam.v1beta1.DeleteIamPolicyResponse\x12\x83\x01\n\x12TestIamPermissions\x12\x35.protopia.cloud.iam.v1beta1.TestIamPermissionsRequest\x1a\x36.protopia.cloud.iam.v1beta1.TestIamPermissionsResponseB6Z4github.com/protopia-ai/cloud/pkg/api/iam/v1beta1;iamb\x06proto3'
  ,
  dependencies=[protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2.DESCRIPTOR,])




_SETIAMPOLICYREQUEST = _descriptor.Descriptor(
  name='SetIamPolicyRequest',
  full_name='protopia.cloud.iam.v1beta1.SetIamPolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource', full_name='protopia.cloud.iam.v1beta1.SetIamPolicyRequest.resource', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy', full_name='protopia.cloud.iam.v1beta1.SetIamPolicyRequest.policy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=112,
  serialized_end=203,
)


_GETIAMPOLICYREQUEST = _descriptor.Descriptor(
  name='GetIamPolicyRequest',
  full_name='protopia.cloud.iam.v1beta1.GetIamPolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.iam.v1beta1.GetIamPolicyRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=238,
)


_LISTIAMPOLICIESREQUEST = _descriptor.Descriptor(
  name='ListIamPoliciesRequest',
  full_name='protopia.cloud.iam.v1beta1.ListIamPoliciesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_token', full_name='protopia.cloud.iam.v1beta1.ListIamPoliciesRequest.page_token', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='protopia.cloud.iam.v1beta1.ListIamPoliciesRequest.page_size', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=303,
)


_LISTIAMPOLICIESRESPONSE = _descriptor.Descriptor(
  name='ListIamPoliciesResponse',
  full_name='protopia.cloud.iam.v1beta1.ListIamPoliciesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='policies', full_name='protopia.cloud.iam.v1beta1.ListIamPoliciesResponse.policies', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='protopia.cloud.iam.v1beta1.ListIamPoliciesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=409,
)


_DELETEIAMPOLICYREQUEST = _descriptor.Descriptor(
  name='DeleteIamPolicyRequest',
  full_name='protopia.cloud.iam.v1beta1.DeleteIamPolicyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.iam.v1beta1.DeleteIamPolicyRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=411,
  serialized_end=447,
)


_DELETEIAMPOLICYRESPONSE = _descriptor.Descriptor(
  name='DeleteIamPolicyResponse',
  full_name='protopia.cloud.iam.v1beta1.DeleteIamPolicyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=449,
  serialized_end=474,
)


_TESTIAMPERMISSIONSREQUEST = _descriptor.Descriptor(
  name='TestIamPermissionsRequest',
  full_name='protopia.cloud.iam.v1beta1.TestIamPermissionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='protopia.cloud.iam.v1beta1.TestIamPermissionsRequest.action', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource', full_name='protopia.cloud.iam.v1beta1.TestIamPermissionsRequest.resource', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=476,
  serialized_end=537,
)


_TESTIAMPERMISSIONSRESPONSE = _descriptor.Descriptor(
  name='TestIamPermissionsResponse',
  full_name='protopia.cloud.iam.v1beta1.TestIamPermissionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed', full_name='protopia.cloud.iam.v1beta1.TestIamPermissionsResponse.allowed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=539,
  serialized_end=584,
)

_SETIAMPOLICYREQUEST.fields_by_name['policy'].message_type = protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2._POLICY
_LISTIAMPOLICIESRESPONSE.fields_by_name['policies'].message_type = protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2._POLICY
DESCRIPTOR.message_types_by_name['SetIamPolicyRequest'] = _SETIAMPOLICYREQUEST
DESCRIPTOR.message_types_by_name['GetIamPolicyRequest'] = _GETIAMPOLICYREQUEST
DESCRIPTOR.message_types_by_name['ListIamPoliciesRequest'] = _LISTIAMPOLICIESREQUEST
DESCRIPTOR.message_types_by_name['ListIamPoliciesResponse'] = _LISTIAMPOLICIESRESPONSE
DESCRIPTOR.message_types_by_name['DeleteIamPolicyRequest'] = _DELETEIAMPOLICYREQUEST
DESCRIPTOR.message_types_by_name['DeleteIamPolicyResponse'] = _DELETEIAMPOLICYRESPONSE
DESCRIPTOR.message_types_by_name['TestIamPermissionsRequest'] = _TESTIAMPERMISSIONSREQUEST
DESCRIPTOR.message_types_by_name['TestIamPermissionsResponse'] = _TESTIAMPERMISSIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SetIamPolicyRequest = _reflection.GeneratedProtocolMessageType('SetIamPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETIAMPOLICYREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.SetIamPolicyRequest)
  })
_sym_db.RegisterMessage(SetIamPolicyRequest)

GetIamPolicyRequest = _reflection.GeneratedProtocolMessageType('GetIamPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETIAMPOLICYREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.GetIamPolicyRequest)
  })
_sym_db.RegisterMessage(GetIamPolicyRequest)

ListIamPoliciesRequest = _reflection.GeneratedProtocolMessageType('ListIamPoliciesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTIAMPOLICIESREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.ListIamPoliciesRequest)
  })
_sym_db.RegisterMessage(ListIamPoliciesRequest)

ListIamPoliciesResponse = _reflection.GeneratedProtocolMessageType('ListIamPoliciesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTIAMPOLICIESRESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.ListIamPoliciesResponse)
  })
_sym_db.RegisterMessage(ListIamPoliciesResponse)

DeleteIamPolicyRequest = _reflection.GeneratedProtocolMessageType('DeleteIamPolicyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEIAMPOLICYREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.DeleteIamPolicyRequest)
  })
_sym_db.RegisterMessage(DeleteIamPolicyRequest)

DeleteIamPolicyResponse = _reflection.GeneratedProtocolMessageType('DeleteIamPolicyResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEIAMPOLICYRESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.DeleteIamPolicyResponse)
  })
_sym_db.RegisterMessage(DeleteIamPolicyResponse)

TestIamPermissionsRequest = _reflection.GeneratedProtocolMessageType('TestIamPermissionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _TESTIAMPERMISSIONSREQUEST,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.TestIamPermissionsRequest)
  })
_sym_db.RegisterMessage(TestIamPermissionsRequest)

TestIamPermissionsResponse = _reflection.GeneratedProtocolMessageType('TestIamPermissionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTIAMPERMISSIONSRESPONSE,
  '__module__' : 'protopia.api.iam.v1beta1.iam_policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.TestIamPermissionsResponse)
  })
_sym_db.RegisterMessage(TestIamPermissionsResponse)


DESCRIPTOR._options = None

_IAMPOLICY = _descriptor.ServiceDescriptor(
  name='IAMPolicy',
  full_name='protopia.cloud.iam.v1beta1.IAMPolicy',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=587,
  serialized_end=1182,
  methods=[
  _descriptor.MethodDescriptor(
    name='SetIamPolicy',
    full_name='protopia.cloud.iam.v1beta1.IAMPolicy.SetIamPolicy',
    index=0,
    containing_service=None,
    input_type=_SETIAMPOLICYREQUEST,
    output_type=protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2._POLICY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetIamPolicy',
    full_name='protopia.cloud.iam.v1beta1.IAMPolicy.GetIamPolicy',
    index=1,
    containing_service=None,
    input_type=_GETIAMPOLICYREQUEST,
    output_type=protopia_dot_api_dot_iam_dot_v1beta1_dot_policy__pb2._POLICY,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListIamPolicies',
    full_name='protopia.cloud.iam.v1beta1.IAMPolicy.ListIamPolicies',
    index=2,
    containing_service=None,
    input_type=_LISTIAMPOLICIESREQUEST,
    output_type=_LISTIAMPOLICIESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteIamPolicy',
    full_name='protopia.cloud.iam.v1beta1.IAMPolicy.DeleteIamPolicy',
    index=3,
    containing_service=None,
    input_type=_DELETEIAMPOLICYREQUEST,
    output_type=_DELETEIAMPOLICYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TestIamPermissions',
    full_name='protopia.cloud.iam.v1beta1.IAMPolicy.TestIamPermissions',
    index=4,
    containing_service=None,
    input_type=_TESTIAMPERMISSIONSREQUEST,
    output_type=_TESTIAMPERMISSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_IAMPOLICY)

DESCRIPTOR.services_by_name['IAMPolicy'] = _IAMPOLICY

# @@protoc_insertion_point(module_scope)



import grpc

from threading import Timer
from oauthlib.oauth2 import BackendApplicationClient
from requests_oauthlib import OAuth2Session


class JwtAuthMetadataPlugin(grpc.AuthMetadataPlugin):
    TOKEN_RENEWAL_GRACE_SECONDS = 60

    def __init__(self, client_id, client_secret, token_url, scope=None):
        """Constructs a new instance of JWT gRPC authentication plugin that injects credentials as call metadata.
            :param client_id: Client id obtained during registration
            :param client_secret: The `client_secret` paired to the `client_id`.
                              This is generally required unless provided in the
                              `auth` tuple. If the value is `None`, it will be
                              omitted from the request, however if the value is
                              an empty string, an empty string will be sent.
            :param token_url: Token endpoint URL, must use HTTPS.
            :param scope: List of scopes you wish to request access to
        """
        if scope is None:
            scope = []
        self.client_id = client_id
        self.client_secret = client_secret
        self.token_url = token_url
        self.access_token = None
        self.token_type = None
        self.sess = OAuth2Session(client=BackendApplicationClient(client_id), scope=scope)
        self.fetch()

    def fetch(self):
        """Generates a new JWT token by performing OAuth2 Client Credentials Flow.
           In addition, it will start a timer that will re-generate the token 60 seconds before it expires.
        """
        resp = self.sess.fetch_token(token_url=self.token_url,
                                     client_id=self.client_id,
                                     client_secret=self.client_secret)
        self.access_token = resp['access_token']
        self.token_type = resp['token_type']
        exp = resp['expires_in']
        Timer(exp - JwtAuthMetadataPlugin.TOKEN_RENEWAL_GRACE_SECONDS, self.fetch)

    def __call__(self, context, callback):
        auth = bytes('%s %s' % (self.token_type, self.access_token), 'utf-8')
        metadata = ((b'authorization', auth),)
        callback(metadata, None)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from protopia.api.noise.v1beta1 import distribution_pb2 as protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2


class NoiseStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetNoiseDistribution = channel.unary_unary(
                '/protopia.cloud.noise.v1beta1.Noise/GetNoiseDistribution',
                request_serializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.GetNoiseDistributionRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.EncryptedNoiseDistribution.FromString,
                )
        self.NotifyUsage = channel.unary_unary(
                '/protopia.cloud.noise.v1beta1.Noise/NotifyUsage',
                request_serializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.Usage.SerializeToString,
                response_deserializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.NotifyUsageResponse.FromString,
                )


class NoiseServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetNoiseDistribution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NotifyUsage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NoiseServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetNoiseDistribution': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNoiseDistribution,
                    request_deserializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.GetNoiseDistributionRequest.FromString,
                    response_serializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.EncryptedNoiseDistribution.SerializeToString,
            ),
            'NotifyUsage': grpc.unary_unary_rpc_method_handler(
                    servicer.NotifyUsage,
                    request_deserializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.Usage.FromString,
                    response_serializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.NotifyUsageResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'protopia.cloud.noise.v1beta1.Noise', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Noise(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetNoiseDistribution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.noise.v1beta1.Noise/GetNoiseDistribution',
            protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.GetNoiseDistributionRequest.SerializeToString,
            protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.EncryptedNoiseDistribution.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def NotifyUsage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/protopia.cloud.noise.v1beta1.Noise/NotifyUsage',
            protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.Usage.SerializeToString,
            protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.NotifyUsageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/iam/v1beta1/role.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/iam/v1beta1/role.proto',
  package='protopia.cloud.iam.v1beta1',
  syntax='proto3',
  serialized_options=b'Z4github.com/protopia-ai/cloud/pkg/api/iam/v1beta1;iam',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#protopia/api/iam/v1beta1/role.proto\x12\x1aprotopia.cloud.iam.v1beta1\"F\n\x04Role\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\tB6Z4github.com/protopia-ai/cloud/pkg/api/iam/v1beta1;iamb\x06proto3'
)




_ROLE = _descriptor.Descriptor(
  name='Role',
  full_name='protopia.cloud.iam.v1beta1.Role',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.iam.v1beta1.Role.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='protopia.cloud.iam.v1beta1.Role.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='protopia.cloud.iam.v1beta1.Role.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='members', full_name='protopia.cloud.iam.v1beta1.Role.members', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=137,
)

DESCRIPTOR.message_types_by_name['Role'] = _ROLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Role = _reflection.GeneratedProtocolMessageType('Role', (_message.Message,), {
  'DESCRIPTOR' : _ROLE,
  '__module__' : 'protopia.api.iam.v1beta1.role_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.Role)
  })
_sym_db.RegisterMessage(Role)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from protopia.api.noise.v1beta1 import distribution_pb2 as protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2
from protopia.api.noise.v1beta1.internal import store_pb2 as protopia_dot_api_dot_noise_dot_v1beta1_dot_internal_dot_store__pb2


class StoreStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StoreNoiseDistribution = channel.unary_unary(
                '/Store/StoreNoiseDistribution',
                request_serializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_internal_dot_store__pb2.StoreNoiseDistributionRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_internal_dot_store__pb2.StoreNoiseDistributionResponse.FromString,
                )
        self.RetrieveNoiseDistribution = channel.unary_unary(
                '/Store/RetrieveNoiseDistribution',
                request_serializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_internal_dot_store__pb2.RetrieveNoiseDistributionRequest.SerializeToString,
                response_deserializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.EncryptedNoiseDistribution.FromString,
                )


class StoreServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StoreNoiseDistribution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RetrieveNoiseDistribution(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StoreServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StoreNoiseDistribution': grpc.unary_unary_rpc_method_handler(
                    servicer.StoreNoiseDistribution,
                    request_deserializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_internal_dot_store__pb2.StoreNoiseDistributionRequest.FromString,
                    response_serializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_internal_dot_store__pb2.StoreNoiseDistributionResponse.SerializeToString,
            ),
            'RetrieveNoiseDistribution': grpc.unary_unary_rpc_method_handler(
                    servicer.RetrieveNoiseDistribution,
                    request_deserializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_internal_dot_store__pb2.RetrieveNoiseDistributionRequest.FromString,
                    response_serializer=protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.EncryptedNoiseDistribution.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Store', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Store(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StoreNoiseDistribution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Store/StoreNoiseDistribution',
            protopia_dot_api_dot_noise_dot_v1beta1_dot_internal_dot_store__pb2.StoreNoiseDistributionRequest.SerializeToString,
            protopia_dot_api_dot_noise_dot_v1beta1_dot_internal_dot_store__pb2.StoreNoiseDistributionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RetrieveNoiseDistribution(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/Store/RetrieveNoiseDistribution',
            protopia_dot_api_dot_noise_dot_v1beta1_dot_internal_dot_store__pb2.RetrieveNoiseDistributionRequest.SerializeToString,
            protopia_dot_api_dot_noise_dot_v1beta1_dot_distribution__pb2.EncryptedNoiseDistribution.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/iam/v1beta1/policy.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/iam/v1beta1/policy.proto',
  package='protopia.cloud.iam.v1beta1',
  syntax='proto3',
  serialized_options=b'Z4github.com/protopia-ai/cloud/pkg/api/iam/v1beta1;iam',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%protopia/api/iam/v1beta1/policy.proto\x12\x1aprotopia.cloud.iam.v1beta1\"\xbe\x01\n\x06Policy\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x39\n\x06\x65\x66\x66\x65\x63t\x18\x03 \x01(\x0e\x32).protopia.cloud.iam.v1beta1.Policy.Effect\x12\x0f\n\x07\x61\x63tions\x18\x04 \x03(\t\x12\x10\n\x08subjects\x18\x05 \x03(\t\"5\n\x06\x45\x66\x66\x65\x63t\x12\x16\n\x12\x45\x46\x46\x45\x43T_UNSPECIFIED\x10\x00\x12\t\n\x05\x41LLOW\x10\x01\x12\x08\n\x04\x44\x45NY\x10\x02\x42\x36Z4github.com/protopia-ai/cloud/pkg/api/iam/v1beta1;iamb\x06proto3'
)



_POLICY_EFFECT = _descriptor.EnumDescriptor(
  name='Effect',
  full_name='protopia.cloud.iam.v1beta1.Policy.Effect',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EFFECT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALLOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DENY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=207,
  serialized_end=260,
)
_sym_db.RegisterEnumDescriptor(_POLICY_EFFECT)


_POLICY = _descriptor.Descriptor(
  name='Policy',
  full_name='protopia.cloud.iam.v1beta1.Policy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protopia.cloud.iam.v1beta1.Policy.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='protopia.cloud.iam.v1beta1.Policy.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effect', full_name='protopia.cloud.iam.v1beta1.Policy.effect', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='actions', full_name='protopia.cloud.iam.v1beta1.Policy.actions', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subjects', full_name='protopia.cloud.iam.v1beta1.Policy.subjects', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _POLICY_EFFECT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=260,
)

_POLICY.fields_by_name['effect'].enum_type = _POLICY_EFFECT
_POLICY_EFFECT.containing_type = _POLICY
DESCRIPTOR.message_types_by_name['Policy'] = _POLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Policy = _reflection.GeneratedProtocolMessageType('Policy', (_message.Message,), {
  'DESCRIPTOR' : _POLICY,
  '__module__' : 'protopia.api.iam.v1beta1.policy_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.iam.v1beta1.Policy)
  })
_sym_db.RegisterMessage(Policy)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/noise/v1beta1/distribution.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/noise/v1beta1/distribution.proto',
  package='protopia.cloud.noise.v1beta1',
  syntax='proto3',
  serialized_options=b'Z8github.com/protopia-ai/cloud/pkg/api/noise/v1beta1;noise',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-protopia/api/noise/v1beta1/distribution.proto\x12\x1cprotopia.cloud.noise.v1beta1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"+\n\x1bGetNoiseDistributionRequest\x12\x0c\n\x04nnid\x18\x01 \x01(\t\"\xda\x01\n\x11NoiseDistribution\x12\x0c\n\x04nnid\x18\x01 \x01(\t\x12\x12\n\nlayer_name\x18\x02 \x01(\t\x12\x16\n\x0elayer_position\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12G\n\x07weights\x18\x05 \x03(\x0b\x32\x36.protopia.cloud.noise.v1beta1.NoiseDistribution.Weight\x1a\x34\n\x06Weight\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05shape\x18\x02 \x03(\x01\x12\r\n\x05value\x18\x03 \x01(\x0c\";\n\x1a\x45ncryptedNoiseDistribution\x12\x0c\n\x04nnid\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\x0c\"\xe7\x01\n\x05Usage\x12\x0c\n\x04nnid\x18\x01 \x01(\t\x12.\n\nstart_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x04span\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12:\n\x06\x61\x63tion\x18\x04 \x01(\x0e\x32*.protopia.cloud.noise.v1beta1.Usage.Action\x12\r\n\x05value\x18\x05 \x01(\x01\",\n\x06\x41\x63tion\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x11\n\rNOISE_SAMPLED\x10\x01\"\x15\n\x13NotifyUsageResponse2\xfc\x01\n\x05Noise\x12\x8b\x01\n\x14GetNoiseDistribution\x12\x39.protopia.cloud.noise.v1beta1.GetNoiseDistributionRequest\x1a\x38.protopia.cloud.noise.v1beta1.EncryptedNoiseDistribution\x12\x65\n\x0bNotifyUsage\x12#.protopia.cloud.noise.v1beta1.Usage\x1a\x31.protopia.cloud.noise.v1beta1.NotifyUsageResponseB:Z8github.com/protopia-ai/cloud/pkg/api/noise/v1beta1;noiseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_USAGE_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='protopia.cloud.noise.v1beta1.Usage.Action',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOISE_SAMPLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=659,
  serialized_end=703,
)
_sym_db.RegisterEnumDescriptor(_USAGE_ACTION)


_GETNOISEDISTRIBUTIONREQUEST = _descriptor.Descriptor(
  name='GetNoiseDistributionRequest',
  full_name='protopia.cloud.noise.v1beta1.GetNoiseDistributionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nnid', full_name='protopia.cloud.noise.v1beta1.GetNoiseDistributionRequest.nnid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=144,
  serialized_end=187,
)


_NOISEDISTRIBUTION_WEIGHT = _descriptor.Descriptor(
  name='Weight',
  full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.Weight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.Weight.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shape', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.Weight.shape', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.Weight.value', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=356,
  serialized_end=408,
)

_NOISEDISTRIBUTION = _descriptor.Descriptor(
  name='NoiseDistribution',
  full_name='protopia.cloud.noise.v1beta1.NoiseDistribution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nnid', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.nnid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer_name', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.layer_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='layer_position', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.layer_position', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weights', full_name='protopia.cloud.noise.v1beta1.NoiseDistribution.weights', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_NOISEDISTRIBUTION_WEIGHT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=408,
)


_ENCRYPTEDNOISEDISTRIBUTION = _descriptor.Descriptor(
  name='EncryptedNoiseDistribution',
  full_name='protopia.cloud.noise.v1beta1.EncryptedNoiseDistribution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nnid', full_name='protopia.cloud.noise.v1beta1.EncryptedNoiseDistribution.nnid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='protopia.cloud.noise.v1beta1.EncryptedNoiseDistribution.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=410,
  serialized_end=469,
)


_USAGE = _descriptor.Descriptor(
  name='Usage',
  full_name='protopia.cloud.noise.v1beta1.Usage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nnid', full_name='protopia.cloud.noise.v1beta1.Usage.nnid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='protopia.cloud.noise.v1beta1.Usage.start_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='span', full_name='protopia.cloud.noise.v1beta1.Usage.span', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='protopia.cloud.noise.v1beta1.Usage.action', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='protopia.cloud.noise.v1beta1.Usage.value', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USAGE_ACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=472,
  serialized_end=703,
)


_NOTIFYUSAGERESPONSE = _descriptor.Descriptor(
  name='NotifyUsageResponse',
  full_name='protopia.cloud.noise.v1beta1.NotifyUsageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=705,
  serialized_end=726,
)

_NOISEDISTRIBUTION_WEIGHT.containing_type = _NOISEDISTRIBUTION
_NOISEDISTRIBUTION.fields_by_name['weights'].message_type = _NOISEDISTRIBUTION_WEIGHT
_USAGE.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_USAGE.fields_by_name['span'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_USAGE.fields_by_name['action'].enum_type = _USAGE_ACTION
_USAGE_ACTION.containing_type = _USAGE
DESCRIPTOR.message_types_by_name['GetNoiseDistributionRequest'] = _GETNOISEDISTRIBUTIONREQUEST
DESCRIPTOR.message_types_by_name['NoiseDistribution'] = _NOISEDISTRIBUTION
DESCRIPTOR.message_types_by_name['EncryptedNoiseDistribution'] = _ENCRYPTEDNOISEDISTRIBUTION
DESCRIPTOR.message_types_by_name['Usage'] = _USAGE
DESCRIPTOR.message_types_by_name['NotifyUsageResponse'] = _NOTIFYUSAGERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetNoiseDistributionRequest = _reflection.GeneratedProtocolMessageType('GetNoiseDistributionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNOISEDISTRIBUTIONREQUEST,
  '__module__' : 'protopia.api.noise.v1beta1.distribution_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.noise.v1beta1.GetNoiseDistributionRequest)
  })
_sym_db.RegisterMessage(GetNoiseDistributionRequest)

NoiseDistribution = _reflection.GeneratedProtocolMessageType('NoiseDistribution', (_message.Message,), {

  'Weight' : _reflection.GeneratedProtocolMessageType('Weight', (_message.Message,), {
    'DESCRIPTOR' : _NOISEDISTRIBUTION_WEIGHT,
    '__module__' : 'protopia.api.noise.v1beta1.distribution_pb2'
    # @@protoc_insertion_point(class_scope:protopia.cloud.noise.v1beta1.NoiseDistribution.Weight)
    })
  ,
  'DESCRIPTOR' : _NOISEDISTRIBUTION,
  '__module__' : 'protopia.api.noise.v1beta1.distribution_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.noise.v1beta1.NoiseDistribution)
  })
_sym_db.RegisterMessage(NoiseDistribution)
_sym_db.RegisterMessage(NoiseDistribution.Weight)

EncryptedNoiseDistribution = _reflection.GeneratedProtocolMessageType('EncryptedNoiseDistribution', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDNOISEDISTRIBUTION,
  '__module__' : 'protopia.api.noise.v1beta1.distribution_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.noise.v1beta1.EncryptedNoiseDistribution)
  })
_sym_db.RegisterMessage(EncryptedNoiseDistribution)

Usage = _reflection.GeneratedProtocolMessageType('Usage', (_message.Message,), {
  'DESCRIPTOR' : _USAGE,
  '__module__' : 'protopia.api.noise.v1beta1.distribution_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.noise.v1beta1.Usage)
  })
_sym_db.RegisterMessage(Usage)

NotifyUsageResponse = _reflection.GeneratedProtocolMessageType('NotifyUsageResponse', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYUSAGERESPONSE,
  '__module__' : 'protopia.api.noise.v1beta1.distribution_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.noise.v1beta1.NotifyUsageResponse)
  })
_sym_db.RegisterMessage(NotifyUsageResponse)


DESCRIPTOR._options = None

_NOISE = _descriptor.ServiceDescriptor(
  name='Noise',
  full_name='protopia.cloud.noise.v1beta1.Noise',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=729,
  serialized_end=981,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetNoiseDistribution',
    full_name='protopia.cloud.noise.v1beta1.Noise.GetNoiseDistribution',
    index=0,
    containing_service=None,
    input_type=_GETNOISEDISTRIBUTIONREQUEST,
    output_type=_ENCRYPTEDNOISEDISTRIBUTION,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyUsage',
    full_name='protopia.cloud.noise.v1beta1.Noise.NotifyUsage',
    index=1,
    containing_service=None,
    input_type=_USAGE,
    output_type=_NOTIFYUSAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_NOISE)

DESCRIPTOR.services_by_name['Noise'] = _NOISE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protopia/api/naming/v1beta1/prn.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protopia/api/naming/v1beta1/prn.proto',
  package='protopia.cloud.naming.v1beta1',
  syntax='proto3',
  serialized_options=b'Z:github.com/protopia-ai/cloud/pkg/api/naming/v1beta1;naming',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%protopia/api/naming/v1beta1/prn.proto\x12\x1dprotopia.cloud.naming.v1beta1\"U\n\x03PRN\x12\x12\n\nenterprise\x18\x01 \x01(\t\x12\x14\n\x0corganization\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\tB<Z:github.com/protopia-ai/cloud/pkg/api/naming/v1beta1;namingb\x06proto3'
)




_PRN = _descriptor.Descriptor(
  name='PRN',
  full_name='protopia.cloud.naming.v1beta1.PRN',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enterprise', full_name='protopia.cloud.naming.v1beta1.PRN.enterprise', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='organization', full_name='protopia.cloud.naming.v1beta1.PRN.organization', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service', full_name='protopia.cloud.naming.v1beta1.PRN.service', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_id', full_name='protopia.cloud.naming.v1beta1.PRN.resource_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=157,
)

DESCRIPTOR.message_types_by_name['PRN'] = _PRN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PRN = _reflection.GeneratedProtocolMessageType('PRN', (_message.Message,), {
  'DESCRIPTOR' : _PRN,
  '__module__' : 'protopia.api.naming.v1beta1.prn_pb2'
  # @@protoc_insertion_point(class_scope:protopia.cloud.naming.v1beta1.PRN)
  })
_sym_db.RegisterMessage(PRN)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from torch import nn
import torch
from torch.distributions.normal import Normal

class Cloak(nn.Module):
    def __init__(self, input_shape=[32, 3, 224, 224]):
        super().__init__()

        self.given_shape = input_shape[1:]

        self.threshold_value = 1.0

        self.locs = torch.nn.Parameter(torch.zeros(input_shape[1:]))
        self.rhos = torch.nn.Parameter(torch.ones(input_shape[1:]) * -4)

        # Normal Distribution buffers
        self.register_buffer("loc", torch.tensor(0.))
        self.register_buffer("scale", torch.tensor(1.))

        self.min_scale = 0.0001
        self.max_scale = 2.0

        self.rhos.requires_grad = False
        self.locs.requires_grad = False

    def print_locs(self):
        print(self.locs)

    def print_rhos(self):
        print(self.rhos)

    def forward(self, x):
        std = (1.0 +torch.tanh(self.rhos))/2*(self.max_scale-self.min_scale) +self.min_scale
        mask = (std < self.threshold_value).float()
        data = x + std * Normal(self.loc, self.scale).sample(self.given_shape)

        x = torch.clamp(
                data * mask + torch.min(x) * (1 - mask) + self.locs,
                torch.min(x),
                torch.max(x)
            )

        return x
